@@ -92,6 +92,8 @@ void HIST_report(HIST h);
 void HIST_timestamp(hrtime_t *timestamp);
 #elif defined(HAVE_GET_HRT)
 void HIST_timestamp(hrt_t *timestamp);
+#elif defined(WIN32)
+void HIST_timestamp(LARGE_INTEGER *timestamp);
 #else
 void HIST_timestamp(struct timeval *timestamp);
 #endif
@@ -104,6 +106,8 @@ void HIST_timestamp(struct timeval *timestamp);
 int delta_micro(hrtime_t *begin, hrtime_t *end);
 #elif defined(HAVE_GET_HRT)
 int delta_micro(hrt_t *begin, hrt_t *end);
+#elif defined(WIN32)
+int delta_micro(LARGE_INTEGER *begin, LARGE_INTEGER *end);
 #else
 int delta_micro(struct timeval *begin, struct timeval *end);
 #endif
