@@ -41,6 +41,9 @@
       MODIFICATION, OR DISTRIBUTION OF THE SOFTWARE OR DOCUMENTATION.
  
 */
+
+#include "netperf_version.h"
+
 char	netserver_id[]="\
 @(#)netserver.c (c) Copyright 1993-2007 Hewlett-Packard Co. Version 2.4.3";
 
@@ -75,6 +78,9 @@ char	netserver_id[]="\
 #if HAVE_STRINGS_H
 # include <strings.h>
 #endif
+#if HAVE_LIMITS_H
+# include <limits.h>
+#endif
 #include <sys/types.h>
 #include <stdio.h>
 #ifndef WIN32
@@ -149,11 +155,37 @@ extern	char	*optarg;
 extern	int	optind, opterr;
 
 #ifndef WIN32
-#define SERVER_ARGS "dL:n:p:v:46"
+#define SERVER_ARGS "dL:n:p:v:V46"
 #else
-#define SERVER_ARGS "dL:n:p:v:46I:i:"
+#define SERVER_ARGS "dL:n:p:v:V46I:i:"
 #endif
 
+/* perhaps one day we will use this as part of only opening a debug
+   log file if debug is set, of course we have to be wary of the base
+   use of "where" and so probably always need "where" pointing
+   "somewhere" or other. */
+void
+open_debug_file() 
+{
+#ifndef WIN32
+#ifndef PATH_MAX
+#define PATH_MAX MAX_PATH
+#endif
+  char FileName[PATH_MAX];   /* for opening the debug log file */
+  strcpy(FileName, DEBUG_LOG_FILE);
+
+  if (where != NULL) fflush(where);
+
+  snprintf(&FileName[strlen(FileName)], sizeof(FileName) - strlen(FileName), "_%d", getpid());
+  if ((where = fopen(FileName, "w")) == NULL) {
+    perror("netserver: debug file");
+    exit(1);
+  }
+
+  chmod(FileName,0644);
+#endif
+
+}
  /* This routine implements the "main event loop" of the netperf	*/
  /* server code. Code above it will have set-up the control connection	*/
  /* so it can just merrily go about its business, which is to		*/
@@ -165,7 +197,9 @@ process_requests()
   
   float	temp_rate;
   
-  
+  if (debug)    open_debug_file();
+
+
   while (1) {
     recv_request();
 
@@ -176,6 +210,7 @@ process_requests()
       /*  dump_request already present in recv_request; redundant? */
       if (!debug) {
 	debug++;
+	open_debug_file();
 	dump_request();
       }
       send_response();
@@ -220,9 +255,12 @@ process_requests()
       bcopy((char *)&temp_rate,
 	    (char *)netperf_response.content.test_specific_data,
 	    sizeof(temp_rate));
+      bcopy((char *)&lib_num_loc_cpus,
+	    (char *)netperf_response.content.test_specific_data + sizeof(temp_rate),
+	    sizeof(lib_num_loc_cpus));
       if (debug) {
 	fprintf(where,"netserver: sending CPU information:");
-	fprintf(where,"rate is %g\n",temp_rate);
+	fprintf(where,"rate is %g num cpu %d\n",temp_rate,lib_num_loc_cpus);
 	fflush(where);
       }
       
@@ -354,6 +392,20 @@ process_requests()
       break;
 #endif
 
+#ifdef WANT_SDP
+    case DO_SDP_STREAM:
+      recv_sdp_stream();
+      break;
+
+    case DO_SDP_MAERTS:
+      recv_sdp_maerts();
+      break;
+
+    case DO_SDP_RR:
+      recv_sdp_rr();
+      break;
+#endif 
+
     default:
       fprintf(where,"unknown test number %d\n",
 	      netperf_request.content.request_type);
@@ -739,6 +791,10 @@ main(int argc, char *argv[])
   BOOL  child = FALSE;
 #endif
   char arg1[BUFSIZ], arg2[BUFSIZ];
+#ifndef PATH_MAX
+#define PATH_MAX MAX_PATH
+#endif
+  char FileName[PATH_MAX];   /* for opening the debug log file */
 
   struct sockaddr name;
   netperf_socklen_t namelen = sizeof(name);
@@ -834,6 +890,10 @@ main(int argc, char *argv[])
       /* say how much to say */
       verbosity = atoi(optarg);
       break;
+    case 'V':
+      printf("Netperf version %s\n",NETPERF_VERSION);
+      exit(0);
+      break;
 #ifdef WIN32
 /*+*+SAF */
 	case 'I':
@@ -854,16 +914,17 @@ main(int argc, char *argv[])
   /* +*+SAF Use DuplicateHandle to force inheritable attribute (or reset it)? */
 
 /*  unlink(DEBUG_LOG_FILE); */
+
+  strcpy(FileName, DEBUG_LOG_FILE);
+    
 #ifndef WIN32
-  if ((where = fopen(DEBUG_LOG_FILE, "w")) == NULL) {
+  snprintf(&FileName[strlen(FileName)], sizeof(FileName) - strlen(FileName), "_%d", getpid());
+  if ((where = fopen(FileName, "w")) == NULL) {
     perror("netserver: debug file");
     exit(1);
   }
 #else
   {
-    char FileName[MAX_PATH];
-    
-    strcpy(FileName, DEBUG_LOG_FILE);
     
     if (child) {
       snprintf(&FileName[strlen(FileName)], sizeof(FileName) - strlen(FileName), "_%x", getpid());
