@@ -1,5 +1,7 @@
+#include "netperf_version.h"
+
 char	netsh_id[]="\
-@(#)netsh.c (c) Copyright 1993-2004 Hewlett-Packard Company. Version 2.4.3";
+@(#)netsh.c (c) Copyright 1993-2007 Hewlett-Packard Company. Version 2.4.3pre";
 
 
 /****************************************************************/
@@ -91,7 +93,7 @@ double atof(const char *);
  /* Some of the args take optional parameters. Since we are using */
  /* getopt to parse the command line, we will tell getopt that they do */
  /* not take parms, and then look for them ourselves */
-#define GLOBAL_CMD_LINE_ARGS "A:a:b:B:CcdDf:F:H:hi:I:k:K:l:L:n:NO:o:P:p:t:T:v:W:w:46"
+#define GLOBAL_CMD_LINE_ARGS "A:a:b:B:CcdDf:F:H:hi:I:k:K:l:L:n:NO:o:P:p:rt:T:v:VW:w:46"
 
 /************************************************************************/
 /*									*/
@@ -203,6 +205,7 @@ int	rem_clean_count;
 int  confidence_level;
 int  iteration_min;
 int  iteration_max;
+int  result_confidence_only = 0;
 
 double interval;
 
@@ -231,6 +234,7 @@ Options:\n\
     -4                Do IPv4\n\
     -6                Do IPv6\n\
     -v verbosity      Specify the verbosity level\n\
+    -V                Display version information and exit\n\
 \n";
 
 /* netperf_usage done as two concatenated strings to make the MS
@@ -264,10 +268,13 @@ Global options:\n\
     -N                Establish no control connection, do 'send' side only\n\
     -p port,lport*    Specify netserver port number and/or local port\n\
     -P 0|1            Don't/Do display test headers\n\
+    -r                Allow confidence to be hit on result only\n\
     -t testname       Specify test to perform\n\
     -T lcpu,rcpu      Request netperf/netserver be bound to local/remote cpu\n\
     -v verbosity      Specify the verbosity level\n\
-    -W send,recv      Set the number of send,recv buffers\n";
+    -W send,recv      Set the number of send,recv buffers\n\
+    -v level          Set the verbosity level (default 1, min 0)\n\
+    -V                Display the netperf version and exit\n";
 
 char netperf_usage2[] = "\n\
 For those options taking two parms, at least one must be specified;\n\
@@ -561,9 +568,15 @@ scan_cmd_line(int argc, char *argv[])
       if (arg2[0] ) {
 	iteration_min = convert(arg2);
       }
+      /* if the iteration_max is < iteration_min make iteration_max
+	 equal iteration_min */
+      if (iteration_max < iteration_min) iteration_max = iteration_min;
+      /* limit minimum to 3 iterations */
+      if (iteration_max < 3) iteration_max = 3;
+      if (iteration_min < 3) iteration_min = 3;
       /* limit maximum to 30 iterations */
-      if(iteration_max>30) iteration_max=30;
-      if(iteration_min>30) iteration_min=30;
+      if (iteration_max > 30) iteration_max = 30;
+      if (iteration_min > 30) iteration_min = 30;
       break;
     case 'I':
       /* set the confidence level (95 or 99) and width */
@@ -578,6 +591,13 @@ scan_cmd_line(int argc, char *argv[])
       if (arg2[0] ) {
 	interval = (double) convert(arg2)/100;
       }
+      /* make sure that iteration_min and iteration_max are at least
+	 at a reasonable default value.  if a -i option has previously
+	 been parsed, these will no longer be 1, so we can check
+	 against 1 */ 
+      if (iteration_min == 1) iteration_min = 3;
+      if (iteration_max == 1) iteration_max = 10;
+
       break;
     case 'k':
       /* local dirty and clean counts */
@@ -634,6 +654,12 @@ scan_cmd_line(int argc, char *argv[])
       /* the header question */
       print_headers = convert(optarg);
       break;
+    case 'r':
+      /* the user wishes that we declare confidence when hit on the
+	 result even if not yet reached on CPU utilization.  only
+	 meaningful if cpu util is enabled */
+      result_confidence_only = 1;
+      break;
     case 't':
       /* set the test name */
       strcpy(test_name,optarg);
@@ -752,6 +778,10 @@ scan_cmd_line(int argc, char *argv[])
       exit(-1);
 #endif
       break;
+    case 'V':
+      printf("Netperf version %s\n",NETPERF_VERSION);
+      exit(0);
+      break;
     };
   }
   /* ok, what should our default hostname and local binding info be?
@@ -908,6 +938,44 @@ scan_cmd_line(int argc, char *argv[])
     }
 #endif
 
+#ifdef WANT_SDP
+    else if((strcasecmp(test_name,"SDP_STREAM") == 0) ||
+	    (strcasecmp(test_name,"SDP_MAERTS") == 0) ||
+	    (strcasecmp(test_name,"SDP_RR") == 0))
+      {
+	scan_sdp_args(argc, argv);
+      }
+#endif
+    
+    /* what is our default value for the output units?  if the test
+       name contains "RR" or "rr" or "Rr" or "rR" then the default is
+       'x' for transactions. otherwise it is 'm' for megabits
+       (10^6) */
+
+    if ('?' == libfmt) {
+      /* we use a series of strstr's here because not everyone has
+	 strcasestr and I don't feel like up or downshifting text */
+      if ((strstr(test_name,"RR")) ||
+	  (strstr(test_name,"rr")) ||
+	  (strstr(test_name,"Rr")) ||
+	  (strstr(test_name,"rR"))) {
+	libfmt = 'x';
+      }
+      else {
+	libfmt = 'm';
+      }
+    }
+    else if ('x' == libfmt) {
+      /* now, a format of 'x' makes no sense for anything other than
+	 an RR test. if someone has been silly enough to try to set
+	 that, we will reset it silently to default - namely 'm' */
+      if ((strstr(test_name,"RR") == NULL) &&
+	  (strstr(test_name,"rr") == NULL) &&
+	  (strstr(test_name,"Rr") == NULL) &&
+	  (strstr(test_name,"rR") == NULL)) {
+	libfmt = 'm';
+      }
+    }
 }
 
 
