@@ -99,6 +99,7 @@ extern int	loc_clean_count;
 extern int  confidence_level;
 extern int  iteration_min;
 extern int  iteration_max;
+extern int  result_confidence_only;
 extern double interval;
 
 extern int cpu_binding_requested;
@@ -131,6 +132,9 @@ extern char
 extern char *
   result_brand;
 
+extern int
+  no_control;
+
 #ifdef WANT_DLPI
 
 extern int
