@@ -258,6 +258,7 @@ struct tcp_tran_rr_results_struct {
 struct	udp_stream_request_struct {
   int	recv_buf_size;
   int	message_size;
+  int   recv_connected;
   int	recv_alignment;
   int	recv_offset;
   int	checksum_off;
@@ -271,6 +272,7 @@ struct	udp_stream_request_struct {
 			   to allow netperf to run through those evil
 			   firewall things */
   int   ipfamily;
+  
 };
 
 struct	udp_stream_response_struct {
@@ -460,3 +462,10 @@ extern void sendfile_tcp_stream(char remotehost[]);
 #if !defined(HAVE_STRUCT_SOCKADDR_STORAGE) && !defined(sockaddr_storage)
 #define sockaddr_storage sockaddr_in
 #endif
+
+#ifdef DO_NBRR
+extern void send_tcp_nbrr(char remote_host[]);
+
+extern void recv_tcp_nbrr();
+#endif
+
